@@ -603,7 +603,7 @@ class IrcBot(object):
                     try:
                         data = data.decode("utf-8")
                     except UnicodeDecodeError:
-                        logging.warning("Decode error")
+                        log("Decode error")
                         continue
                     debug(
                         "DECODED DATA FROM SERVER: \n", 40 * "-", "\n", data, 40 * "-", "\n"
@@ -805,6 +805,9 @@ class IrcBot(object):
                 msg = re.sub(r"\003\d\d(?:,\d\d)?", "", msg)
                 debug(f"PARSED MESSAGE: {msg}")
 
+                if channel not in self.channels:
+                    await self._enqueue_message(f"PART {channel}")
+
                 if (
                     channel in self.replyIntents
                     and sender_nick in self.replyIntents[channel]
